@@ -20,7 +20,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '2.104000';
+$VERSION        = '3.000000';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -1897,6 +1897,14 @@ sub Marpa::R2::Scanless::R::default_g1_start_closure {
     return $closure;
 } ## end sub Marpa::R2::Scanless::R::default_g1_start_closure
 
+# not to be documented
+sub Marpa::R2::Scanless::R::earley_set_size {
+    my ($self, $set_id) = @_;
+    # OK if set ID is undef, just pass it on.
+    return $self->[Marpa::R2::Internal::Scanless::R::THICK_G1_RECCE]
+        ->earley_set_size($set_id);
+}
+
 1;
 
 # vim: expandtab shiftwidth=4:
